( cd usr/lib ; rm -rf libtimidity.so )
( cd usr/lib ; ln -sf libtimidity-0.1.so.0.0.0 libtimidity.so )
( cd usr/lib ; rm -rf libtimidity-0.1.so.0 )
( cd usr/lib ; ln -sf libtimidity-0.1.so.0.0.0 libtimidity-0.1.so.0 )
